##  Antipatterns
This section addresses antipatterns involving ineffective or counterproductive ways of modeling the tech category in SAP LeanIX.
  * Don’t confuse tech category and IT components - tech category is the grouping of the IT components.
  * Don’t confuse tech category and technical platform (an optional platform type in meta model v3) - the tech category is a logical grouping of technologies of similar functions (for example, all of your databases), while technical platform is a technical grouping of IT components of one type (for example, all of your Oracle databases) in relation to the strategic initiatives, business capabilities, and objectives.
